@@ -1,5 +1,5 @@
-/* This file is part of the KDE project
-   Copyright (C) 2006 Tom Albers <tomalbers@kde.nl>
+/*
+   Copyright (C) 2006 Tom Albers <toma.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,6 +22,4 @@
 
 bool QueryDPMSTimeouts( Display* display, int& standby, int& suspend, int& off );
 
-QPixmap takeScreenshot( int );
-
 #endif
